==> haskell-bimap-0.5.0-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bimap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bimap
version:              0.5.0
visibility:           public
id:                   bimap-0.5.0-3PrkdGKYUEE1grLr9B6VVj
key:                  bimap-0.5.0-3PrkdGKYUEE1grLr9B6VVj
license:              BSD-3-Clause
copyright:            Stuart Cook and contributors 2008, Joel Williamson 2015
maintainer:           Joel Williamson <joel@joelwilliamson.ca>
author:               Stuart Cook and contributors 2008, Joel Williamson 2015
homepage:             https://github.com/joelwilliamson/bimap
synopsis:             Bidirectional mapping between two key types
description:
    A data structure representing a bidirectional mapping between two
    key types. Each value in the bimap is associated with exactly one
    value of the opposite type.

category:             Data
abi:                  b6fc339047681c4efd727a4ad7d00b54
exposed:              True
exposed-modules:      Data.Bimap
hidden-modules:       Data.BimapExt
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bimap-0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bimap-0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bimap-0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bimap
hs-libraries:         HSbimap-0.5.0-3PrkdGKYUEE1grLr9B6VVj
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0 exceptions-0.10.5

haddock-interfaces:   /usr/share/doc/haskell-bimap/html/bimap.haddock
haddock-html:         /usr/share/doc/haskell-bimap/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bimap-0.5.0-131-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bimap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bimap
version:              0.5.0
visibility:           public
id:                   bimap-0.5.0-A8WKwj2K9ZuCvQVneJXBgB
key:                  bimap-0.5.0-A8WKwj2K9ZuCvQVneJXBgB
license:              BSD-3-Clause
copyright:            Stuart Cook and contributors 2008, Joel Williamson 2015
maintainer:           Joel Williamson <joel@joelwilliamson.ca>
author:               Stuart Cook and contributors 2008, Joel Williamson 2015
homepage:             https://github.com/joelwilliamson/bimap
synopsis:             Bidirectional mapping between two key types
description:
    A data structure representing a bidirectional mapping between two
    key types. Each value in the bimap is associated with exactly one
    value of the opposite type.

category:             Data
abi:                  c112624b1063e3e6e512f577f53ae1d1
exposed:              True
exposed-modules:      Data.Bimap
hidden-modules:       Data.BimapExt
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bimap-0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bimap-0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bimap-0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bimap
hs-libraries:         HSbimap-0.5.0-A8WKwj2K9ZuCvQVneJXBgB
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0 exceptions-0.10.5

haddock-interfaces:   /usr/share/doc/haskell-bimap/html/bimap.haddock
haddock-html:         /usr/share/doc/haskell-bimap/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
